==> kfilecoder-src-0.1.4.tar.gz: kfilecoder-src-0.1.4/kfilecoder/kfilecoder.moc.cpp <==
/****************************************************************************
** KFileCoderApp meta object code from reading C++ file 'kfilecoder.h'
**
** Created: Sun Jun 6 19:06:21 1999
**      by: The Qt Meta Object Compiler ($Revision: 2.25.2.11 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#if !defined(Q_MOC_OUTPUT_REVISION)
#define Q_MOC_OUTPUT_REVISION 2
#elif Q_MOC_OUTPUT_REVISION != 2
#error "Moc format conflict - please regenerate all moc files"
#endif

#include "kfilecoder.h"
#include <qmetaobject.h>


const char *KFileCoderApp::className() const
{
    return "KFileCoderApp";
}

QMetaObject *KFileCoderApp::metaObj = 0;


#if QT_VERSION >= 200
static QMetaObjectInit init_KFileCoderApp(&KFileCoderApp::staticMetaObject);

#endif

void KFileCoderApp::initMetaObject()
{
    if ( metaObj )
	return;
    if ( strcmp(KTMainWindow::className(), "KTMainWindow") != 0 )
	badSuperclassWarning("KFileCoderApp","KTMainWindow");

#if QT_VERSION >= 200
    staticMetaObject();
}

void KFileCoderApp::staticMetaObject()
{
    if ( metaObj )
	return;
    KTMainWindow::staticMetaObject();
#else

    KTMainWindow::initMetaObject();
#endif

    typedef void(KFileCoderApp::*m1_t0)(int);
    typedef void(KFileCoderApp::*m1_t1)(int);
    typedef void(KFileCoderApp::*m1_t2)();
    typedef void(KFileCoderApp::*m1_t3)();
    typedef void(KFileCoderApp::*m1_t4)();
    typedef void(KFileCoderApp::*m1_t5)(int);
    typedef void(KFileCoderApp::*m1_t6)();
    typedef void(KFileCoderApp::*m1_t7)();
    typedef void(KFileCoderApp::*m1_t8)();
    typedef void(KFileCoderApp::*m1_t9)();
    typedef void(KFileCoderApp::*m1_t10)();
    typedef void(KFileCoderApp::*m1_t11)();
    typedef void(KFileCoderApp::*m1_t12)();
    typedef void(KFileCoderApp::*m1_t13)();
    typedef void(KFileCoderApp::*m1_t14)();
    typedef void(KFileCoderApp::*m1_t15)(const char*);
    typedef void(KFileCoderApp::*m1_t16)(const char*);
    typedef void(KFileCoderApp::*m1_t17)(QCloseEvent*);
    m1_t0 v1_0 = &KFileCoderApp::commandCallback;
    m1_t1 v1_1 = &KFileCoderApp::statusCallback;
    m1_t2 v1_2 = &KFileCoderApp::slotFileNewWindow;
    m1_t3 v1_3 = &KFileCoderApp::slotFileNew;
    m1_t4 v1_4 = &KFileCoderApp::slotFileOpen;
    m1_t5 v1_5 = &KFileCoderApp::slotOpenRecent;
    m1_t6 v1_6 = &KFileCoderApp::slotFileClose;
    m1_t7 v1_7 = &KFileCoderApp::slotFileProperties;
    m1_t8 v1_8 = &KFileCoderApp::slotFileQuit;
    m1_t9 v1_9 = &KFileCoderApp::slotArchiveAdd;
    m1_t10 v1_10 = &KFileCoderApp::slotArchiveExtractAll;
    m1_t11 v1_11 = &KFileCoderApp::slotArchiveExtractSel;
    m1_t12 v1_12 = &KFileCoderApp::slotArchiveDelete;
    m1_t13 v1_13 = &KFileCoderApp::slotViewToolBar;
    m1_t14 v1_14 = &KFileCoderApp::slotViewStatusBar;
    m1_t15 v1_15 = &KFileCoderApp::slotStatusMsg;
    m1_t16 v1_16 = &KFileCoderApp::slotStatusHelpMsg;
    m1_t17 v1_17 = &KFileCoderApp::closeEvent;
    QMetaData *slot_tbl = new QMetaData[18];
    slot_tbl[0].name = "commandCallback(int)";
    slot_tbl[1].name = "statusCallback(int)";
    slot_tbl[2].name = "slotFileNewWindow()";
    slot_tbl[3].name = "slotFileNew()";
    slot_tbl[4].name = "slotFileOpen()";
    slot_tbl[5].name = "slotOpenRecent(int)";
    slot_tbl[6].name = "slotFileClose()";
    slot_tbl[7].name = "slotFileProperties()";
    slot_tbl[8].name = "slotFileQuit()";
    slot_tbl[9].name = "slotArchiveAdd()";
    slot_tbl[10].name = "slotArchiveExtractAll()";
    slot_tbl[11].name = "slotArchiveExtractSel()";
    slot_tbl[12].name = "slotArchiveDelete()";
    slot_tbl[13].name = "slotViewToolBar()";
    slot_tbl[14].name = "slotViewStatusBar()";
    slot_tbl[15].name = "slotStatusMsg(const char*)";
    slot_tbl[16].name = "slotStatusHelpMsg(const char*)";
    slot_tbl[17].name = "closeEvent(QCloseEvent*)";
    slot_tbl[0].ptr = *((QMember*)&v1_0);
    slot_tbl[1].ptr = *((QMember*)&v1_1);
    slot_tbl[2].ptr = *((QMember*)&v1_2);
    slot_tbl[3].ptr = *((QMember*)&v1_3);
    slot_tbl[4].ptr = *((QMember*)&v1_4);
    slot_tbl[5].ptr = *((QMember*)&v1_5);
    slot_tbl[6].ptr = *((QMember*)&v1_6);
    slot_tbl[7].ptr = *((QMember*)&v1_7);
    slot_tbl[8].ptr = *((QMember*)&v1_8);
    slot_tbl[9].ptr = *((QMember*)&v1_9);
    slot_tbl[10].ptr = *((QMember*)&v1_10);
    slot_tbl[11].ptr = *((QMember*)&v1_11);
    slot_tbl[12].ptr = *((QMember*)&v1_12);
    slot_tbl[13].ptr = *((QMember*)&v1_13);
    slot_tbl[14].ptr = *((QMember*)&v1_14);
    slot_tbl[15].ptr = *((QMember*)&v1_15);
    slot_tbl[16].ptr = *((QMember*)&v1_16);
    slot_tbl[17].ptr = *((QMember*)&v1_17);
    metaObj = new QMetaObject( "KFileCoderApp", "KTMainWindow",
	slot_tbl, 18,
	0, 0 );
}

==> kfilecoder-src-0.2.3.tar.gz: kfilecoder-src-0.2.3/kfilecoder/kfilecoder.moc.cpp <==
/****************************************************************************
** KFileCoderApp meta object code from reading C++ file 'kfilecoder.h'
**
** Created: Wed Jun 16 21:14:21 1999
**      by: The Qt Meta Object Compiler ($Revision: 2.25.2.11 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#if !defined(Q_MOC_OUTPUT_REVISION)
#define Q_MOC_OUTPUT_REVISION 2
#elif Q_MOC_OUTPUT_REVISION != 2
#error "Moc format conflict - please regenerate all moc files"
#endif

#include "kfilecoder.h"
#include <qmetaobject.h>


const char *KFileCoderApp::className() const
{
    return "KFileCoderApp";
}

QMetaObject *KFileCoderApp::metaObj = 0;


#if QT_VERSION >= 200
static QMetaObjectInit init_KFileCoderApp(&KFileCoderApp::staticMetaObject);

#endif

void KFileCoderApp::initMetaObject()
{
    if ( metaObj )
	return;
    if ( strcmp(KTMainWindow::className(), "KTMainWindow") != 0 )
	badSuperclassWarning("KFileCoderApp","KTMainWindow");

#if QT_VERSION >= 200
    staticMetaObject();
}

void KFileCoderApp::staticMetaObject()
{
    if ( metaObj )
	return;
    KTMainWindow::staticMetaObject();
#else

    KTMainWindow::initMetaObject();
#endif

    typedef void(KFileCoderApp::*m1_t0)(int);
    typedef void(KFileCoderApp::*m1_t1)(int);
    typedef void(KFileCoderApp::*m1_t2)();
    typedef void(KFileCoderApp::*m1_t3)();
    typedef void(KFileCoderApp::*m1_t4)();
    typedef void(KFileCoderApp::*m1_t5)(int);
    typedef void(KFileCoderApp::*m1_t6)();
    typedef void(KFileCoderApp::*m1_t7)();
    typedef void(KFileCoderApp::*m1_t8)();
    typedef void(KFileCoderApp::*m1_t9)();
    typedef void(KFileCoderApp::*m1_t10)();
    typedef void(KFileCoderApp::*m1_t11)();
    typedef void(KFileCoderApp::*m1_t12)();
    typedef void(KFileCoderApp::*m1_t13)();
    typedef void(KFileCoderApp::*m1_t14)();
    typedef void(KFileCoderApp::*m1_t15)(const char*);
    typedef void(KFileCoderApp::*m1_t16)(const char*);
    typedef void(KFileCoderApp::*m1_t17)(QCloseEvent*);
    typedef void(KFileCoderApp::*m1_t18)();
    typedef void(KFileCoderApp::*m1_t19)();
    m1_t0 v1_0 = &KFileCoderApp::commandCallback;
    m1_t1 v1_1 = &KFileCoderApp::statusCallback;
    m1_t2 v1_2 = &KFileCoderApp::slotFileNewWindow;
    m1_t3 v1_3 = &KFileCoderApp::slotFileNew;
    m1_t4 v1_4 = &KFileCoderApp::slotFileOpen;
    m1_t5 v1_5 = &KFileCoderApp::slotOpenRecent;
    m1_t6 v1_6 = &KFileCoderApp::slotFileClose;
    m1_t7 v1_7 = &KFileCoderApp::slotFileProperties;
    m1_t8 v1_8 = &KFileCoderApp::slotFileQuit;
    m1_t9 v1_9 = &KFileCoderApp::slotArchiveAdd;
    m1_t10 v1_10 = &KFileCoderApp::slotArchiveExtractAll;
    m1_t11 v1_11 = &KFileCoderApp::slotArchiveExtractSel;
    m1_t12 v1_12 = &KFileCoderApp::slotArchiveDelete;
    m1_t13 v1_13 = &KFileCoderApp::slotViewToolBar;
    m1_t14 v1_14 = &KFileCoderApp::slotViewStatusBar;
    m1_t15 v1_15 = &KFileCoderApp::slotStatusMsg;
    m1_t16 v1_16 = &KFileCoderApp::slotStatusHelpMsg;
    m1_t17 v1_17 = &KFileCoderApp::closeEvent;
    m1_t18 v1_18 = &KFileCoderApp::slotHelpWebSite;
    m1_t19 v1_19 = &KFileCoderApp::slotHelpAbout;
    QMetaData *slot_tbl = new QMetaData[20];
    slot_tbl[0].name = "commandCallback(int)";
    slot_tbl[1].name = "statusCallback(int)";
    slot_tbl[2].name = "slotFileNewWindow()";
    slot_tbl[3].name = "slotFileNew()";
    slot_tbl[4].name = "slotFileOpen()";
    slot_tbl[5].name = "slotOpenRecent(int)";
    slot_tbl[6].name = "slotFileClose()";
    slot_tbl[7].name = "slotFileProperties()";
    slot_tbl[8].name = "slotFileQuit()";
    slot_tbl[9].name = "slotArchiveAdd()";
    slot_tbl[10].name = "slotArchiveExtractAll()";
    slot_tbl[11].name = "slotArchiveExtractSel()";
    slot_tbl[12].name = "slotArchiveDelete()";
    slot_tbl[13].name = "slotViewToolBar()";
    slot_tbl[14].name = "slotViewStatusBar()";
    slot_tbl[15].name = "slotStatusMsg(const char*)";
    slot_tbl[16].name = "slotStatusHelpMsg(const char*)";
    slot_tbl[17].name = "closeEvent(QCloseEvent*)";
    slot_tbl[18].name = "slotHelpWebSite()";
    slot_tbl[19].name = "slotHelpAbout()";
    slot_tbl[0].ptr = *((QMember*)&v1_0);
    slot_tbl[1].ptr = *((QMember*)&v1_1);
    slot_tbl[2].ptr = *((QMember*)&v1_2);
    slot_tbl[3].ptr = *((QMember*)&v1_3);
    slot_tbl[4].ptr = *((QMember*)&v1_4);
    slot_tbl[5].ptr = *((QMember*)&v1_5);
    slot_tbl[6].ptr = *((QMember*)&v1_6);
    slot_tbl[7].ptr = *((QMember*)&v1_7);
    slot_tbl[8].ptr = *((QMember*)&v1_8);
    slot_tbl[9].ptr = *((QMember*)&v1_9);
    slot_tbl[10].ptr = *((QMember*)&v1_10);
    slot_tbl[11].ptr = *((QMember*)&v1_11);
    slot_tbl[12].ptr = *((QMember*)&v1_12);
    slot_tbl[13].ptr = *((QMember*)&v1_13);
    slot_tbl[14].ptr = *((QMember*)&v1_14);
    slot_tbl[15].ptr = *((QMember*)&v1_15);
    slot_tbl[16].ptr = *((QMember*)&v1_16);
    slot_tbl[17].ptr = *((QMember*)&v1_17);
    slot_tbl[18].ptr = *((QMember*)&v1_18);
    slot_tbl[19].ptr = *((QMember*)&v1_19);
    metaObj = new QMetaObject( "KFileCoderApp", "KTMainWindow",
	slot_tbl, 20,
	0, 0 );
}
